@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use overload
   '""' => \&stringify,
@@ -350,7 +350,7 @@ sub conj ($) {
 }
 
 #
-## log(a + b*i) = log(a^2 + b^2)/2 + atan(b/a)*i
+## log(a + b*i) = log(a^2 + b^2)/2 + atan2(b, a)*i    -- where a,b are real
 #
 
 sub log {
@@ -758,7 +758,7 @@ sub atan ($) {
 }
 
 #
-## atan2(x, y) = atan(x/y)
+## atan2(a, b) = -i * log((b + a*i) / sqrt(a^2 + b^2))
 #
 
 sub atan2 {
@@ -767,7 +767,18 @@ sub atan2 {
     $x = __PACKAGE__->new($x) if ref($x) ne __PACKAGE__;
     $y = __PACKAGE__->new($y) if ref($y) ne __PACKAGE__;
 
-    $x->div($y)->atan;
+    state $i = __PACKAGE__->new(0, 1);
+
+    my $t = $x->mul($i);
+
+    $t->{a} += $y->{a};
+    $t->{b} += $y->{b};
+
+    $t = $t->div($x->mul($x)->add($y->mul($y))->sqrt)->log;
+
+    @{$t}{'a', 'b'} = ($t->{b}, -$t->{a});
+
+    $t;
 }
 
 #
